/// <reference types="express" />
import { Request } from '@loopback/rest';
import { IAuthUserWithPermissions, ILogger, SuccessResponse } from '@loopx/core';
import { AuthClient } from '../../models';
import { AuthCodeGeneratorFn, JWTSignerFn, JwtPayloadFn } from '../../providers';
import { AuthClientRepository, OtpCacheRepository, RefreshTokenRepository, RevokedTokenRepository, RoleRepository, TenantConfigRepository, UserCredentialsRepository, UserLevelPermissionRepository, UserRepository, UserTenantRepository } from '../../repositories';
import { LoginHelperService, TokenService } from '../../services';
import { CodeResponse, LoginRequest } from './';
import { AuthUser } from './models/auth-user.model';
import { ResetPassword } from './models/reset-password.dto';
import { TokenResponse } from './models/token-response.dto';
export declare class LoginController {
    private readonly client;
    private readonly user;
    authClientRepository: AuthClientRepository;
    userRepo: UserRepository;
    otpCacheRepo: OtpCacheRepository;
    roleRepo: RoleRepository;
    utPermsRepo: UserLevelPermissionRepository;
    userTenantRepo: UserTenantRepository;
    refreshTokenRepo: RefreshTokenRepository;
    revokedTokensRepo: RevokedTokenRepository;
    tenantConfigRepo: TenantConfigRepository;
    userCredsRepository: UserCredentialsRepository;
    private readonly req;
    private readonly getJwtPayload;
    private readonly loginHelperService;
    private readonly tokenService;
    private readonly getAuthCode;
    private readonly jwtSigner;
    logger: ILogger;
    constructor(client: AuthClient | undefined, user: AuthUser | undefined, authClientRepository: AuthClientRepository, userRepo: UserRepository, otpCacheRepo: OtpCacheRepository, roleRepo: RoleRepository, utPermsRepo: UserLevelPermissionRepository, userTenantRepo: UserTenantRepository, refreshTokenRepo: RefreshTokenRepository, revokedTokensRepo: RevokedTokenRepository, tenantConfigRepo: TenantConfigRepository, userCredsRepository: UserCredentialsRepository, req: Request, getJwtPayload: JwtPayloadFn, loginHelperService: LoginHelperService, tokenService: TokenService, getAuthCode: AuthCodeGeneratorFn, jwtSigner: JWTSignerFn<object>, logger: ILogger);
    login(req: LoginRequest, client: AuthClient | undefined, user: AuthUser | undefined): Promise<CodeResponse>;
    loginWithClientUser(req: LoginRequest): Promise<TokenResponse>;
    changePassword(req: ResetPassword, auth: string, currentUser: IAuthUserWithPermissions): Promise<SuccessResponse>;
}
