"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LoginController = void 0;
const tslib_1 = require("tslib");
const berrors_1 = require("berrors");
const context_1 = require("@loopback/context");
const core_1 = require("@loopback/core");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const authentication_1 = require("@bleco/authentication");
const authorization_1 = require("@bleco/authorization");
const core_2 = require("@loopx/core");
const keys_1 = require("../../keys");
const providers_1 = require("../../providers");
const repositories_1 = require("../../repositories");
const services_1 = require("../../services");
const _1 = require("./");
const reset_password_dto_1 = require("./models/reset-password.dto");
const token_response_dto_1 = require("./models/token-response.dto");
let LoginController = exports.LoginController = class LoginController {
    constructor(client, user, authClientRepository, userRepo, otpCacheRepo, roleRepo, utPermsRepo, userTenantRepo, refreshTokenRepo, revokedTokensRepo, tenantConfigRepo, userCredsRepository, req, getJwtPayload, loginHelperService, tokenService, getAuthCode, jwtSigner, logger) {
        this.client = client;
        this.user = user;
        this.authClientRepository = authClientRepository;
        this.userRepo = userRepo;
        this.otpCacheRepo = otpCacheRepo;
        this.roleRepo = roleRepo;
        this.utPermsRepo = utPermsRepo;
        this.userTenantRepo = userTenantRepo;
        this.refreshTokenRepo = refreshTokenRepo;
        this.revokedTokensRepo = revokedTokensRepo;
        this.tenantConfigRepo = tenantConfigRepo;
        this.userCredsRepository = userCredsRepository;
        this.req = req;
        this.getJwtPayload = getJwtPayload;
        this.loginHelperService = loginHelperService;
        this.tokenService = tokenService;
        this.getAuthCode = getAuthCode;
        this.jwtSigner = jwtSigner;
        this.logger = logger;
    }
    async login(req, client, user) {
        await this.loginHelperService.verifyClientUserLogin(req, client, user);
        try {
            if (!this.user || !this.client) {
                // Control should never reach here
                this.logger.error(`${authentication_1.AuthenticationErrors.ClientInvalid.name} :: Control should never reach here`);
                throw new authentication_1.AuthenticationErrors.ClientInvalid();
            }
            const token = await this.getAuthCode(this.client, this.user);
            return {
                code: token,
            };
        }
        catch (error) {
            this.logger.error(error.message);
            throw new authentication_1.AuthenticationErrors.InvalidCredentials();
        }
    }
    async loginWithClientUser(req) {
        var _a;
        await this.loginHelperService.verifyClientUserLogin(req, this.client, this.user);
        try {
            if (!this.user || !this.client) {
                // Control should never reach here
                this.logger.error(`${authentication_1.AuthenticationErrors.ClientInvalid.name} :: Control should never reach here`);
                throw new authentication_1.AuthenticationErrors.ClientInvalid();
            }
            const payload = {
                clientId: this.client.clientId,
                user: this.user,
            };
            if (((_a = payload.user) === null || _a === void 0 ? void 0 : _a.id) && !(await this.userRepo.firstTimeUser(payload.user.id))) {
                await this.userRepo.updateLastLogin(payload.user.id);
            }
            return await this.tokenService.createJWT(payload, this.client, "ACCESS" /* LoginType.ACCESS */);
        }
        catch (error) {
            this.logger.error(error);
            throw new authentication_1.AuthenticationErrors.InvalidCredentials();
        }
    }
    async changePassword(req, auth, currentUser) {
        const token = auth === null || auth === void 0 ? void 0 : auth.replace(/bearer /i, '');
        if (!token || !req.refreshToken) {
            throw new core_2.AuthErrors.TokenMissing();
        }
        const refreshTokenModel = await this.refreshTokenRepo.get(req.refreshToken);
        if (refreshTokenModel.accessToken !== token) {
            throw new authentication_1.AuthenticationErrors.TokenInvalid();
        }
        if (refreshTokenModel.username !== req.username || currentUser.username !== req.username) {
            throw new authorization_1.AuthorizationErrors.NotAllowedAccess();
        }
        if (req.password && req.password.length <= 0) {
            throw new core_2.AuthErrors.PasswordInvalid();
        }
        let changePasswordResponse;
        if (req.oldPassword) {
            changePasswordResponse = await this.userRepo.updatePassword(req.username, req.oldPassword, req.password);
        }
        else {
            changePasswordResponse = await this.userRepo.changePassword(req.username, req.password);
        }
        if (!changePasswordResponse) {
            throw new berrors_1.BErrors.UnprocessableEntity('Unable to set password !');
        }
        const userTenant = await this.userTenantRepo.findOne({
            where: {
                userId: changePasswordResponse.id,
                tenantId: currentUser.tenantId,
            },
        });
        if (!userTenant) {
            throw new core_2.AuthErrors.UserInactive();
        }
        if (userTenant.status && userTenant.status < core_2.UserStatus.ACTIVE) {
            await this.userRepo.userTenants(changePasswordResponse.id).patch({
                status: core_2.UserStatus.ACTIVE,
            });
        }
        await this.revokedTokensRepo.set(token, { token });
        await this.refreshTokenRepo.delete(req.refreshToken);
        return new core_2.SuccessResponse({
            success: true,
        });
    }
};
tslib_1.__decorate([
    (0, authentication_1.authenticateClient)(authentication_1.STRATEGY.CLIENT_PASSWORD),
    (0, authentication_1.authenticate)(authentication_1.STRATEGY.LOCAL),
    (0, authorization_1.authorize)({ permissions: ['*'] }),
    (0, rest_1.post)('/auth/login', {
        description: 'Gets you the code that will be used for getting token (webapps)',
        responses: {
            [core_2.STATUS_CODE.OK]: {
                description: 'Auth Code that you can use to generate access and refresh tokens using the POST /auth/token API',
                content: {
                    [core_2.CONTENT_TYPE.JSON]: {
                        schema: (0, rest_1.getModelSchemaRef)(_1.LoginCodeResponse),
                    },
                },
            },
            ...core_2.ErrorCodes,
        },
    }),
    tslib_1.__param(0, (0, rest_1.requestBody)()),
    tslib_1.__param(1, (0, context_1.inject)(authentication_1.AuthenticationBindings.CURRENT_CLIENT)),
    tslib_1.__param(2, (0, context_1.inject)(authentication_1.AuthenticationBindings.CURRENT_USER)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [_1.LoginRequest, Object, Object]),
    tslib_1.__metadata("design:returntype", Promise)
], LoginController.prototype, "login", null);
tslib_1.__decorate([
    (0, authentication_1.authenticateClient)(authentication_1.STRATEGY.CLIENT_PASSWORD),
    (0, authentication_1.authenticate)(authentication_1.STRATEGY.OAUTH2_RESOURCE_OWNER_GRANT),
    (0, authorization_1.authorize)({ permissions: ['*'] }),
    (0, rest_1.post)('/auth/login-token', {
        description: 'Gets you refresh token and access token in one hit. (mobile app)',
        responses: {
            [core_2.STATUS_CODE.OK]: {
                description: 'Token Response Model',
                content: {
                    [core_2.CONTENT_TYPE.JSON]: {
                        schema: { [core_2.X_TS_TYPE]: token_response_dto_1.TokenResponse },
                    },
                },
            },
            ...core_2.ErrorCodes,
        },
    }),
    tslib_1.__param(0, (0, rest_1.requestBody)()),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [_1.LoginRequest]),
    tslib_1.__metadata("design:returntype", Promise)
], LoginController.prototype, "loginWithClientUser", null);
tslib_1.__decorate([
    (0, authentication_1.authenticate)(authentication_1.STRATEGY.BEARER, { passReqToCallback: true }),
    (0, authorization_1.authorize)({ permissions: ['*'] }),
    (0, rest_1.patch)(`auth/change-password`, {
        security: core_2.OPERATION_SECURITY_SPEC,
        responses: {
            [core_2.STATUS_CODE.OK]: {
                description: 'If User password successfully changed.',
            },
        },
    }),
    tslib_1.__param(0, (0, rest_1.requestBody)({
        content: {
            [core_2.CONTENT_TYPE.JSON]: {
                schema: (0, rest_1.getModelSchemaRef)(reset_password_dto_1.ResetPassword, { partial: true }),
            },
        },
    })),
    tslib_1.__param(1, rest_1.param.header.string('Authorization')),
    tslib_1.__param(2, (0, context_1.inject)(authentication_1.AuthenticationBindings.CURRENT_USER)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [reset_password_dto_1.ResetPassword, String, Object]),
    tslib_1.__metadata("design:returntype", Promise)
], LoginController.prototype, "changePassword", null);
exports.LoginController = LoginController = tslib_1.__decorate([
    tslib_1.__param(0, (0, context_1.inject)(authentication_1.AuthenticationBindings.CURRENT_CLIENT)),
    tslib_1.__param(1, (0, context_1.inject)(authentication_1.AuthenticationBindings.CURRENT_USER)),
    tslib_1.__param(2, (0, repository_1.repository)(repositories_1.AuthClientRepository)),
    tslib_1.__param(3, (0, repository_1.repository)(repositories_1.UserRepository)),
    tslib_1.__param(4, (0, repository_1.repository)(repositories_1.OtpCacheRepository)),
    tslib_1.__param(5, (0, repository_1.repository)(repositories_1.RoleRepository)),
    tslib_1.__param(6, (0, repository_1.repository)(repositories_1.UserLevelPermissionRepository)),
    tslib_1.__param(7, (0, repository_1.repository)(repositories_1.UserTenantRepository)),
    tslib_1.__param(8, (0, repository_1.repository)(repositories_1.RefreshTokenRepository)),
    tslib_1.__param(9, (0, repository_1.repository)(repositories_1.RevokedTokenRepository)),
    tslib_1.__param(10, (0, repository_1.repository)(repositories_1.TenantConfigRepository)),
    tslib_1.__param(11, (0, repository_1.repository)(repositories_1.UserCredentialsRepository)),
    tslib_1.__param(12, (0, context_1.inject)(rest_1.RestBindings.Http.REQUEST)),
    tslib_1.__param(13, (0, context_1.inject)(keys_1.AuthServiceBindings.JWTPayloadProvider)),
    tslib_1.__param(14, (0, core_1.service)(services_1.LoginHelperService)),
    tslib_1.__param(15, (0, core_1.service)(services_1.TokenService)),
    tslib_1.__param(16, (0, context_1.inject)(providers_1.AuthCodeBindings.AUTH_CODE_GENERATOR_PROVIDER)),
    tslib_1.__param(17, (0, context_1.inject)(providers_1.AuthCodeBindings.JWT_SIGNER)),
    tslib_1.__param(18, (0, context_1.inject)(core_2.LOGGER.LOGGER_INJECT)),
    tslib_1.__metadata("design:paramtypes", [Object, Object, repositories_1.AuthClientRepository,
        repositories_1.UserRepository,
        repositories_1.OtpCacheRepository,
        repositories_1.RoleRepository,
        repositories_1.UserLevelPermissionRepository,
        repositories_1.UserTenantRepository,
        repositories_1.RefreshTokenRepository,
        repositories_1.RevokedTokenRepository,
        repositories_1.TenantConfigRepository,
        repositories_1.UserCredentialsRepository, Object, Function, services_1.LoginHelperService,
        services_1.TokenService, Function, Function, Object])
], LoginController);
//# sourceMappingURL=login.controller.js.map