"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PasswordlessController = void 0;
const tslib_1 = require("tslib");
const jwt = tslib_1.__importStar(require("jsonwebtoken"));
const context_1 = require("@loopback/context");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const authentication_1 = require("@bleco/authentication");
const authorization_1 = require("@bleco/authorization");
const core_1 = require("@loopx/core");
const providers_1 = require("../../providers");
const repositories_1 = require("../../repositories");
const _1 = require("./");
const otp_send_request_dto_1 = require("./models/otp-send-request.dto");
const basePath = '/auth/passwordless';
let PasswordlessController = exports.PasswordlessController = class PasswordlessController {
    constructor(authClientRepository, userRepo, otpCacheRepo, userCredsRepository, logger) {
        this.authClientRepository = authClientRepository;
        this.userRepo = userRepo;
        this.otpCacheRepo = otpCacheRepo;
        this.userCredsRepository = userCredsRepository;
        this.logger = logger;
    }
    // OTP
    async startPasswordless(req) {
        // This is intentional
    }
    async verifyPasswordless(req, user, codeWriter) {
        const otpCache = await this.otpCacheRepo.get(req.key);
        if (user === null || user === void 0 ? void 0 : user.id) {
            otpCache.userId = user.id;
        }
        const codePayload = {
            clientId: otpCache.clientId,
            userId: otpCache.userId,
        };
        const token = await codeWriter(jwt.sign(codePayload, otpCache.clientSecret, {
            expiresIn: 180,
            audience: otpCache.clientId,
            issuer: process.env.JWT_ISSUER,
            algorithm: 'HS256',
        }));
        return {
            code: token,
        };
    }
};
tslib_1.__decorate([
    (0, authentication_1.authenticateClient)(authentication_1.STRATEGY.CLIENT_PASSWORD),
    (0, authentication_1.authenticate)(authentication_1.STRATEGY.OTP, {}, undefined, providers_1.VerifyBindings.PASSWORDLESS_VERIFIER),
    (0, authorization_1.authorize)({ permissions: ['*'] }),
    (0, rest_1.post)(`${basePath}/start`, {
        description: 'Sends OTP',
        responses: {
            [core_1.STATUS_CODE.OK]: {
                description: 'Sends otp to user',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: Object,
                },
            },
            ...core_1.ErrorCodes,
        },
    }),
    tslib_1.__param(0, (0, rest_1.requestBody)()),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [otp_send_request_dto_1.OtpSendRequest]),
    tslib_1.__metadata("design:returntype", Promise)
], PasswordlessController.prototype, "startPasswordless", null);
tslib_1.__decorate([
    (0, authentication_1.authenticate)(authentication_1.STRATEGY.OTP, {}, undefined, providers_1.VerifyBindings.PASSWORDLESS_VERIFIER),
    (0, authorization_1.authorize)({ permissions: ['*'] }),
    (0, rest_1.post)(`${basePath}/verify`, {
        description: 'Gets you the code that will be used for getting token (webapps)',
        responses: {
            [core_1.STATUS_CODE.OK]: {
                description: 'Auth Code that you can use to generate access and refresh tokens using the POST /auth/token API',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: Object,
                },
            },
            ...core_1.ErrorCodes,
        },
    }),
    tslib_1.__param(0, (0, rest_1.requestBody)()),
    tslib_1.__param(1, (0, context_1.inject)(authentication_1.AuthenticationBindings.CURRENT_USER)),
    tslib_1.__param(2, (0, context_1.inject)(providers_1.AuthCodeBindings.CODEWRITER_PROVIDER)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [_1.OtpLoginRequest, Object, Function]),
    tslib_1.__metadata("design:returntype", Promise)
], PasswordlessController.prototype, "verifyPasswordless", null);
exports.PasswordlessController = PasswordlessController = tslib_1.__decorate([
    tslib_1.__param(0, (0, repository_1.repository)(repositories_1.AuthClientRepository)),
    tslib_1.__param(1, (0, repository_1.repository)(repositories_1.UserRepository)),
    tslib_1.__param(2, (0, repository_1.repository)(repositories_1.OtpCacheRepository)),
    tslib_1.__param(3, (0, repository_1.repository)(repositories_1.UserCredentialsRepository)),
    tslib_1.__param(4, (0, context_1.inject)(core_1.LOGGER.LOGGER_INJECT)),
    tslib_1.__metadata("design:paramtypes", [repositories_1.AuthClientRepository,
        repositories_1.UserRepository,
        repositories_1.OtpCacheRepository,
        repositories_1.UserCredentialsRepository, Object])
], PasswordlessController);
//# sourceMappingURL=passwordless.controller.js.map