"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthaVerifyProvider = void 0;
const tslib_1 = require("tslib");
const context_1 = require("@loopback/context");
const repository_1 = require("@loopback/repository");
const authentication_1 = require("@bleco/authentication");
const providers_1 = require("../../../providers");
const repositories_1 = require("../../../repositories");
const auth_user_model_1 = require("../models/auth-user.model");
let AuthaVerifyProvider = exports.AuthaVerifyProvider = class AuthaVerifyProvider {
    constructor(userRepository, userCredsRepository, signupProvider, preVerifyProvider, postVerifyProvider) {
        this.userRepository = userRepository;
        this.userCredsRepository = userCredsRepository;
        this.signupProvider = signupProvider;
        this.preVerifyProvider = preVerifyProvider;
        this.postVerifyProvider = postVerifyProvider;
    }
    value() {
        return async (accessToken, refreshToken, profile) => {
            const or = [];
            if (profile.email) {
                or.push({ email: profile.email });
            }
            if (profile.phone) {
                or.push({ phone: profile.phone });
            }
            if (profile.username) {
                or.push({ username: profile.username });
            }
            let user = await this.userRepository.findOne({
                where: { or },
            });
            user = await this.preVerifyProvider(accessToken, refreshToken, profile, user);
            if (!user) {
                const newUser = await this.signupProvider(profile);
                if (newUser) {
                    user = newUser;
                }
                else {
                    throw new authentication_1.AuthenticationErrors.InvalidCredentials();
                }
            }
            const creds = await this.userCredsRepository.findOne({
                where: {
                    userId: user.id,
                },
            });
            if (!creds || creds.authProvider !== 'autha' || creds.authId !== profile.id) {
                throw new authentication_1.AuthenticationErrors.InvalidCredentials();
            }
            const authUser = new auth_user_model_1.AuthUser({
                ...user,
                id: user.id,
            });
            authUser.permissions = [];
            authUser.externalAuthToken = accessToken;
            authUser.externalRefreshToken = refreshToken;
            return this.postVerifyProvider(profile, authUser);
        };
    }
};
exports.AuthaVerifyProvider = AuthaVerifyProvider = tslib_1.__decorate([
    tslib_1.__param(0, (0, repository_1.repository)(repositories_1.UserRepository)),
    tslib_1.__param(1, (0, repository_1.repository)(repositories_1.UserCredentialsRepository)),
    tslib_1.__param(2, (0, context_1.inject)(providers_1.SignUpBindings.AUTHA_SIGNUP_PROVIDER)),
    tslib_1.__param(3, (0, context_1.inject)(providers_1.VerifyBindings.AUTHA_PRE_VERIFY_PROVIDER)),
    tslib_1.__param(4, (0, context_1.inject)(providers_1.VerifyBindings.AUTHA_POST_VERIFY_PROVIDER)),
    tslib_1.__metadata("design:paramtypes", [repositories_1.UserRepository,
        repositories_1.UserCredentialsRepository, Function, Function, Function])
], AuthaVerifyProvider);
//# sourceMappingURL=autha-verify.provider.js.map