"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SignupHelperService = void 0;
const tslib_1 = require("tslib");
const context_1 = require("@loopback/context");
const core_1 = require("@loopback/core");
const repository_1 = require("@loopback/repository");
const core_2 = require("@loopx/core");
const errors_1 = require("../errors");
const repositories_1 = require("../repositories");
const validation_service_1 = require("./validation.service");
let SignupHelperService = exports.SignupHelperService = class SignupHelperService {
    constructor(userRepository, validationService, logger) {
        this.userRepository = userRepository;
        this.validationService = validationService;
        this.logger = logger;
    }
    /**
     * Validate the signup request
     *
     * @param req
     */
    async validateSignupFastRequest(req) {
        await this.validationService.validateUsername(req.username);
        this.validationService.validatePassword(req.password);
        if (!req.email && !req.phone) {
            throw new errors_1.ValidationErrors.EmailOrPhoneRequired();
        }
        if (req.email) {
            await this.validationService.validateEmail(req.email);
        }
        if (req.phone) {
            await this.validationService.validatePhone(req.phone);
        }
    }
};
exports.SignupHelperService = SignupHelperService = tslib_1.__decorate([
    (0, core_1.injectable)({ scope: core_1.BindingScope.SINGLETON }),
    tslib_1.__param(0, (0, repository_1.repository)(repositories_1.UserRepository)),
    tslib_1.__param(1, (0, core_1.service)(validation_service_1.ValidationService)),
    tslib_1.__param(2, (0, context_1.inject)(core_2.LOGGER.LOGGER_INJECT)),
    tslib_1.__metadata("design:paramtypes", [repositories_1.UserRepository,
        validation_service_1.ValidationService, Object])
], SignupHelperService);
//# sourceMappingURL=signup-helper.service.js.map